import React, { useContext, useEffect, useCallback } from "react";
import {
  ApplicationStateContext,
  ApplicationDispatchContext
} from "../../../state/ApplicationContexts";
import * as api from "../api";
import MachinesList from "./MachinesList";
import { PowerSettingsNew, LastPage } from "@material-ui/icons";
import { useToast } from "../../../hooks";

const MachinesContainer = () => {
  const state = useContext(ApplicationStateContext);
  const dispatchActions = useContext(ApplicationDispatchContext);

  const { success, error } = useToast();

  const handleReadMachines = useCallback(async () => {
    const machines = await api.readMachines();
    const data = Object.assign(machines, { loaded: true });
    dispatchActions.onNetworkChange("machines", data);
  }, [dispatchActions]);

  const wakeMachine = machine => async () => {
    const result = await api.wakeMachine(machine.macAddress);
    if (result.success) {
      success(result.status);
    } else {
      error(result.status);
    }
  };

  const pingMachine = machine => async () => {
    const result = await api.pingMachine(
      machine.iPv4Address || machine.machineName
    );
    if (result.success) {
      success(result.status);
    } else {
      error(result.status);
    }
  };

  const actions = [
    {
      code: "wake",
      effect: wakeMachine,
      icon: PowerSettingsNew,
      tooltip: "Wake"
    },
    {
      code: "ping",
      effect: pingMachine,
      icon: LastPage,
      tooltip: "Ping"
    }
  ];

  useEffect(() => {
    if (!state.network.machines.loaded) {
      handleReadMachines();
    }
  }, [handleReadMachines, state.network.machines.loaded]);

  return (
    <MachinesList
      dense={true}
      machines={state.network.machines}
      actions={actions}
    />
  );
};

export default MachinesContainer;
